(*

Plot the stable arm along with two planes cutting it at
two potential initial points

The program PhaseDiagram3D.m must have been run before
this program

*)

Print["Running InitialConditions3D.m"];

<<DisplayOff.m;
If[DisplayFigs == True,<<DisplayOn.m];
(*
kOzConstVal   = 2.4;
HikOzConstVal = 7;
*)
kOzConstVal = 3.;
HikOzConstVal = 5.5;
(*
The following code set the center point of the plane at the intersection
of the plane with the stable arm.  It was replaced by the next two lines
of code, which put the center of the planes at the steady-state to make 
it easier to see how the variables compare to their steady-state values.

cOzIntersection    = DevolvFunc2DkOzVScOz[kOzConstVal];
cdotOcIntersection = DevolvFunc2DcOzVScdotOc[cOzIntersection];
*)
cOzIntersection    = cOzSS;
cdotOcIntersection = cdotOcSS;

LowIntersectionPoint = {cOzIntersection,cdotOcIntersection,kOzConstVal};

LowIntersectionPoint3D = Show[Graphics3D[{PointSize[.01]
,Point[LowIntersectionPoint]}]
];

kOzConstPlane = Plot3D[kOzConstVal,{cOz,cOzIntersection - .7, cOzIntersection+.7}
,{cdotOc,cdotOcIntersection-.6,cdotOcIntersection+.6}
,PlotPoints->5
];

cOzVSkOzWherekOzEqInitalValue = ParametricPlot3D[{cOz,cdotOcMax,kOzConstVal,Thickness[.0001]}
,{cOz,cOzMin,cOzMax}
];

cdotOcVSkOzWherekOzEqInitalValue = ParametricPlot3D[{cOzMax,cdotOc,kOzConstVal,Thickness[.0001]}
,{cdotOc,cdotOcMin,cdotOcMax}
];

HicOzVSkOzWherekOzEqInitalValue = ParametricPlot3D[{cOz,cdotOcMax,HikOzConstVal,Thickness[.0001]}
,{cOz,cOzMin,cOzMax}
];

HicdotOcVSkOzWherekOzEqInitalValue = ParametricPlot3D[{cOzMax,cdotOc,HikOzConstVal,Thickness[.0001]}
,{cdotOc,cdotOcMin,cdotOcMax}
];

(*
The following code set the center point of the plane at the intersection
of the plane with the stable arm.

HicOzIntersection    = DevolvFuncRight2DkOzVScOz[HikOzConstVal];
HicdotOcIntersection = DevolvFuncRight2DcOzVScdotOc[HicOzIntersection];
*)

HicOzIntersection    = cOzSS;
HicdotOcIntersection = cdotOcSS;

HiIntersectionPoint = {HicOzIntersection,HicdotOcIntersection,HikOzConstVal};

HiIntersectionPoint3D = Show[Graphics3D[{PointSize[.01]
,Point[HiIntersectionPoint]}]
];

HikOzConstPlane = Plot3D[HikOzConstVal,{cOz,HicOzIntersection - .7, HicOzIntersection+.7}
,{cdotOc,HicdotOcIntersection-.6,HicdotOcIntersection+.6}
,PlotPoints->5
];

LightHikOzConstPlane = Show[{Graphics3D[GrayLevel[.9]],HikOzConstPlane},Lighting->False
];

LightkOzConstPlane = Show[{Graphics3D[GrayLevel[.9]],kOzConstPlane},Lighting->False
];

HicOzVSkOzWherekOzEqInitalValue = ParametricPlot3D[{cOz,cdotOcMax,HikOzConstVal,Thickness[.0001]}
,{cOz,cOzMin,cOzMax}
];

HicdotOcVSkOzWherekOzEqInitalValue = ParametricPlot3D[{cOzMax,cdotOc,HikOzConstVal,Thickness[.0001]}
,{cdotOc,cdotOcMin,cdotOcMax}
];


LineFromBottomLowInit3D = DashingLineFromBottom[{cOzIntersection,cdotOcIntersection,kOzConstVal}];
LineFromBackLowInit3D   = DashingLineFromBack[{cOzIntersection,cdotOcIntersection,kOzConstVal}];

LineFromBottomHiInit3D  = DashingLineFromBottom[{HicOzIntersection,HicdotOcIntersection,HikOzConstVal}];
LineFromBackHiInit3D    = DashingLineFromBack[  {HicOzIntersection,HicdotOcIntersection,HikOzConstVal}];


If[DisplayFinalFigs == True,<<DisplayOn.m];


InitialConditions3D = Show[
StableArm3D
,LightkOzConstPlane
,LightHikOzConstPlane
,LowIntersectionPoint3D
,HiIntersectionPoint3D
,cOzVSkOzWherekOzEqInitalValue
,cdotOcVSkOzWherekOzEqInitalValue
,HicOzVSkOzWherekOzEqInitalValue
,HicdotOcVSkOzWherekOzEqInitalValue
,StableArmcOzVScdotOc
,StableArmcOzVSkOz
(*
,cOzAlldotIsZerocOzVScdotOc
,cdotOcAlldotIsZerocOzVScdotOc
,cOzVSkOzWherekOzAlldotEqZeroLocus3D
*)
,LineFromBottomSS3D
,LineFromBackSS3D
,LineFromBottomLowInit3D
,LineFromBackLowInit3D
,LineFromBottomHiInit3D
,LineFromBackHiInit3D
,SS
,PlotRange->{{cOzMin3DAxis,cOzMax3DPlot}
	,{InvcOzAlldotIsZeroUpper[cOzLeftStartingPoint],cdotOcMax3DPlot}
	,{kOzMin3DPlot,DevolvFunc2DcOzVSkOz[cOzMax3DPlot]}}
,AxesLabel->{"c/z","\!\(\(c\& . \)/c\)","k/z"}
,Axes->True
,ViewPoint->{-1.2,-2.6,.8}
(* ,ViewPoint->{-1.6,-2.6,.8} *)
,BoxRatios->{1,1,1}
,Ticks->{{{0,"(0,0,0)"}},{},{}}
,Lighting->False
,AxesEdge->{Automatic,{-1,-1},Automatic}
,DisplayFunction->$DisplayFunction
,ImageSize->{72 6.,72 6./GoldenRatio}
]


