(*

This program makes the 3D phase diagram which combines the 
two 2D phase diagrams. 

*)

Print["Running PhaseDiagram3D.m"];

<<DisplayOff.m;
If[DisplayFigs == True,<<DisplayOn.m];

(* Draw the projection of the cOzAlldot=0 curve into the bottom face *)
cOzAlldotIsZerocOzVScdotOc = 
ParametricPlot3D[{cOz,InvcOzAlldotIsZeroUpper[cOz],0,Thickness[.0001]}
,{cOz,cOzLeftStartingPoint,cOzRightStartingPoint}
,DisplayFunction->Identity
]

(* Draw the projection of the cdotOcAlldot=0 curve into the bottom face *)
cdotOcAlldotIsZerocOzVScdotOc = ParametricPlot3D[{cOz,cdotOcIsZeroUpper[cOz],0,Thickness[.0001]}
,{cOz,cOzLeftStartingPoint,cOzRightStartingPoint}
,DisplayFunction->Identity
]

cOzMin3DPlot = Max[MinPtscOz,cOzMin];
cOzMax3DPlot = Min[MaxPtscOz,cOzMax];

StableArm3D = ParametricPlot3D[
{cOz,DevolvFunc2DcOzVScdotOc[cOz],DevolvFunc2DcOzVSkOz[cOz]}
,{cOz,cOzMin3DPlot,cOzMax3DPlot}
,DisplayFunction->Identity
]

(* Draw the projection of the stable arm into the back face *)
StableArmcOzVSkOz = ParametricPlot3D[
{cOz,cdotOcMax,DevolvFunc2DcOzVSkOz[cOz]}
,{cOz,cOzMin3DPlot,cOzMax3DPlot}
,DisplayFunction->Identity
];

(* Draw the projection of the stable arm into the back face, Gray *)
StableArmcOzVSkOzGray = ParametricPlot3D[
{cOz,cdotOcMax,DevolvFunc2DcOzVSkOz[cOz],GrayLevel[.5]}
,{cOz,cOzMin3DPlot,cOzMax3DPlot}
,DisplayFunction->Identity
];

(* Draw the projection of the stable arm into the bottom face *) 
StableArmcOzVScdotOc = ParametricPlot3D[
{cOz,DevolvFunc2DcOzVScdotOc[cOz],0}
,{cOz,cOzMin3DPlot,cOzMax3DPlot}
,DisplayFunction->Identity
];

(* Draw the projection of the stable arm into the bottom face, Gray *) 
StableArmcOzVScdotOcGray = ParametricPlot3D[
{cOz,DevolvFunc2DcOzVScdotOc[cOz],0,GrayLevel[.5]}
,{cOz,cOzMin3DPlot,cOzMax3DPlot}
,DisplayFunction->Identity
];

(* Draw the projection of the stable arm into the right face *)
StableArmkOzVScdotOc = ParametricPlot3D[
{cOzMax3DPlot,DevolvFunc2DkOzVScdotOc[kOz],kOz}
,{kOz,DevolvFunc2DcOzVSkOz[cOzMin3DPlot],DevolvFunc2DcOzVSkOz[cOzMax3DPlot]}
,DisplayFunction->Identity
]

(* Draw the projection of the stable arm into the right face, Gray *)
StableArmkOzVScdotOc = ParametricPlot3D[
{cOzMax3DPlot,DevolvFunc2DkOzVScdotOc[kOz],kOz, GrayLevel[.5]}
,{kOz,DevolvFunc2DcOzVSkOz[cOzMin3DPlot],DevolvFunc2DcOzVSkOz[cOzMax3DPlot]}
,DisplayFunction->Identity
]

(* Draw the projection of the kOzAlldot=0 curve in the back  *)

cOzVSkOzWherekOzAlldotEqZeroLocus3D = ParametricPlot3D[{cOz,cdotOcMax,cOzVSkOzWherekOzAlldotEqZero[cOz],Thickness[.0001]}
,{cOz,cOzMin3DPlot,kOzVScOzWherekOzAlldotEqZero[DevolvFunc2DcOzVSkOz[cOzMax3DPlot]]}
,DisplayFunction->Identity
];

Clear[DashingLineFromBack];
DashingLineFromBack[Point3D_] := Block[{cOz=Point3D[[1]],cdotOc=Point3D[[2]],kOz=Point3D[[3]]},
Return[Graphics3D[{Thickness[.0001],Dashing[{.005,.005}],Line[{{cOz,cdotOcMax,kOz},Point3D}]}]]
]

Clear[DashingLineFromBottom];
DashingLineFromBottom[Point3D_] := Block[{cOz=Point3D[[1]],cdotOc=Point3D[[2]],kOz=Point3D[[3]]},
Return[Graphics3D[{Thickness[.0001],Dashing[{.005,.005}],Line[{{cOz,cdotOc,kOzMin3DPlot},Point3D}]}]]
]

LineFromBottomLeft3D = DashingLineFromBottom[{cOzLeftStartingPoint,DevolvFuncLeft2DcOzVScdotOc[cOzLeftStartingPoint],DevolvFuncLeft2DcOzVSkOz[cOzLeftStartingPoint]}];
LineFromBackLeft3D   = DashingLineFromBack[{cOzLeftStartingPoint,DevolvFuncLeft2DcOzVScdotOc[cOzLeftStartingPoint],DevolvFuncLeft2DcOzVSkOz[cOzLeftStartingPoint]}];

LineFromBottomRight3D = DashingLineFromBottom[{cOzRightStartingPoint,DevolvFuncRight2DcOzVScdotOc[cOzRightStartingPoint],DevolvFuncRight2DcOzVSkOz[cOzRightStartingPoint]}];
LineFromBackRight3D   = DashingLineFromBack[{cOzRightStartingPoint,DevolvFuncRight2DcOzVScdotOc[cOzRightStartingPoint],DevolvFuncRight2DcOzVSkOz[cOzRightStartingPoint]}];

LineFromBottomSS3D = DashingLineFromBottom[{cOzSS,cdotOcSS,kOzSS}];
LineFromBackSS3D   = DashingLineFromBack[{cOzSS,cdotOcSS,kOzSS}];

(* Create a dot at the Steady State *)
SS = Show[Graphics3D[{PointSize[.01],Point[{cOzSS,cdotOcSS,kOzSS}]}]
,DisplayFunction->Identity
];

<<DisplayOff.m;If[DisplayFinalFigs == True,<<DisplayOn.m];

PhaseDiagram3D = Show[StableArm3D
,StableArmcOzVScdotOc
,StableArmcOzVSkOz
,cOzAlldotIsZerocOzVScdotOc
,cdotOcAlldotIsZerocOzVScdotOc
,cOzVSkOzWherekOzAlldotEqZeroLocus3D
,LineFromBottomSS3D
,LineFromBackSS3D
,LineFromBackLeft3D
,LineFromBottomLeft3D
,LineFromBackRight3D
,LineFromBottomRight3D
,SS
,PlotRange->{{cOzMin3DAxis,cOzMax3DPlot}
	,{InvcOzAlldotIsZeroUpper[cOzLeftStartingPoint],cdotOcMax3DPlot}
	,{kOzMin3DPlot,DevolvFunc2DcOzVSkOz[cOzMax3DPlot]}}
,AxesLabel->{"c/z","\!\(\(c\& . \)/c\)","k/z"}
,Axes->True
,ViewPoint->{-1.6,-2.6,.8}
,Lighting->True
,BoxRatios->{1,1,1}
,DisplayFunction->$DisplayFunction
,Ticks->{{{0,"(0,0,0)"}},{},{}}
,AxesEdge->{Automatic,{-1,-1},Automatic}
,ImageSize->{72 6.,72 6./GoldenRatio}
]

