(* 

Program to produce phase diagram in (c/z,cdot/c) space

It is necessary to read in the parameters in params.m, the boundaries
in boundaries.m, and to run the eqns_of_motion.m program before
running this one

*)

Print["Running PhaseDiagramcOzVScdotOc.m"];

<<DisplayOff.m;If[DisplayFigs == True,<<DisplayOn.m];

cOzAlldotIsZeroLocus = Plot[InvcOzAlldotIsZeroUpper[cOz]
,{cOz,cOzMincOzVScdotOcPlot,cOzMaxcOzVScdotOcPlot}
,PlotStyle->Thickness[.002]
];

cdotOcIsZeroLoci = Plot[{cdotOcIsZeroLower[cOz],cdotOcIsZeroUpper[cOz]}
,{cOz,cOzMin,cOzMaxcOzVScdotOcPlot}
,PlotStyle->Thickness[.002]
];

cOzVScdotOcAlldotEqZeroLoci = Show[cdotOcIsZeroLoci,cOzAlldotIsZeroLocus];

StableArm2DcOzVScdotOcLeft  = 
Plot[DevolvFuncLeft2DcOzVScdotOc[x]
,{x,Max[.01,cOzLeftStartingPoint],cOzSS-epsilon}
];

cOzLeftEdgeOfStableArm = cOzLeftStartingPoint;

StableArm2DcOzVScdotOcRight =  
Plot[DevolvFuncRight2DcOzVScdotOc[x]
,{x,cOzRightStartingPoint+.4,cOzSS+epsilon}
];

cOzRightEdgeOfStableArm = cOzRightStartingPoint+.4;

Clear[Evolve2D];
Evolve2D[EvolvingList_] := Block[{
	LastElement   = Last[EvolvingList],
	cOzPoint   = LastElement[[1]],
	cdotOcPoint= LastElement[[2]]
},
Return[Join[EvolvingList,{
{cOzPoint    + cOzAlldot[   cOzPoint,cdotOcPoint]/ScaleFactor,
 cdotOcPoint + cdotOcAlldot[cOzPoint,cdotOcPoint]/ScaleFactor}}
]];
]

Clear[EvolveSteps2D];
EvolveSteps2D[InitialList_,NumberOfSteps_] :=
Block[{EvolvingList = InitialList},

Do[
LastElement = Last[EvolvingList];

If[   Abs[Last[EvolvingList][[1]]] > cOzMaxDevolving
   || Abs[Last[EvolvingList][[2]]] > cdotOcMaxDevolving,
(* then *) Break[]];
(* else *) 
EvolvingList = Evolve2D[EvolvingList];

,{i,NumberOfSteps}];
Return[EvolvingList]];


EvolvingPointsLeftBelow     = EvolveSteps2D[
{{Max[.01,cOzLeftStartingPoint],
 DevolvFuncLeft2DcOzVScdotOc[Max[.01,cOzLeftStartingPoint]]}
 -{0,.09}}
,100];
EvolvingPointsLeftBelowPlot = ListPlot[EvolvingPointsLeftBelow
	,PlotJoined->True,PlotStyle->{Dashing[{.005,.005}],Thickness[.001]}
	,DisplayFunction->Identity
];

EvolvingPointsLeftAbove     = EvolveSteps2D[
{{Max[.01,cOzLeftStartingPoint],
 DevolvFuncLeft2DcOzVScdotOc[Max[.01,cOzLeftStartingPoint]]}
+{0,.09}}
,100];

EvolvingPointsLeftAbovePlot = ListPlot[EvolvingPointsLeftAbove
	,PlotJoined->True,PlotStyle->{Dashing[{.005,.005}],Thickness[.001]}
	,DisplayFunction->Identity
];

EvolvingPointsRightAbove = EvolveSteps2D[
{{cOzRightStartingPoint,
  DevolvFuncRight2DcOzVScdotOc[cOzRightStartingPoint]+.1}}
,100];

EvolvingPointsRightAbovePlot = ListPlot[EvolvingPointsRightAbove
	,PlotJoined->True,PlotStyle->{Dashing[{.005,.005}],Thickness[.001]}
];

EvolvingPointsRightBelow = EvolveSteps2D[{{cOzRightStartingPoint,DevolvFuncRight2DcOzVScdotOc[cOzRightStartingPoint]-.1}},100]
EvolvingPointsRightBelowPlot = ListPlot[EvolvingPointsRightBelow
	,PlotJoined->True,PlotStyle->{Dashing[{.005,.005}],Thickness[.001]}
];	

EvolvingPointsRightSS2 = EvolveSteps2D[{{1.5,-1}},100];
EvolvingPointsRightSS2Plot = ListPlot[EvolvingPointsRightSS2,
	PlotJoined->True,PlotStyle->{Dashing[{.005,.005}],Thickness[.001]}];

EvolvingPointsLeftBelowSS2 = EvolveSteps2D[{{.05,-1.2}},100]
EvolvingPointsLeftBelowSS2Plot = ListPlot[EvolvingPointsLeftBelowSS2,
	PlotJoined->True,PlotStyle->{Dashing[{.005,.005}],Thickness[.001]}];

EvolvingPointsLeftAboveSS2 = EvolveSteps2D[{{.05,.1}},100]
EvolvingPointsLeftAboveSS2Plot = ListPlot[EvolvingPointsLeftAboveSS2,
	PlotJoined->True,PlotStyle->{Dashing[{.005,.005}],Thickness[.001]}];

If[DisplayFinalFigs == True,<<DisplayOn.m,<<DisplayOff.m];

$DefaultFont = {"Times-Roman",12};
PhaseDiagcOzVScdotOcHabits = Show[StableArm2DcOzVScdotOcLeft
,StableArm2DcOzVScdotOcRight
,cOzVScdotOcAlldotEqZeroLoci
,EvolvingPointsLeftAbovePlot
,EvolvingPointsLeftBelowPlot
,EvolvingPointsRightAbovePlot
,EvolvingPointsRightBelowPlot
,EvolvingPointsLeftBelowSS2Plot
,EvolvingPointsLeftAboveSS2Plot
,EvolvingPointsRightSS2Plot
,Graphics[Text["\!\(\(c\& . \)/c\) = 0" ,{cOzMaxcOzVScdotOcPlot+.35,-.35}]]
,Graphics[Text["\!\(\(c\& . \)/c\) = 0" ,{cOzMaxcOzVScdotOcPlot+.3,1.7}]]
,Graphics[Text["\!\(\(\((c/z)\)\& . \)\) = 0"       ,{cOzMaxcOzVScdotOcPlot+.3,2.10}]]
,Graphics[Text["Stable Arm",{cOzMaxcOzVScdotOcPlot+.50,1.35}]]
,Graphics[Text["0",{-.1,-.2}]]
,Graphics[Text["1",{  1,-.2}]]
,Graphics[Text["\!\(SS\_1\)",{cOzSS-.06,cdotOcSS+.15}]]
,Graphics[Text["\!\(SS\_2\)",{cOzSS2-.28,cdotOcSS2-.5}]]
,AxesLabel->{"c/z","\!\(\(c\& . \)/c\)"}
,DisplayFunction->$DisplayFunction
,Ticks->None 
,PlotRange->{{cOzMincOzVScdotOcAxis,cOzMaxcOzVScdotOcAxis},{cdotOcMincOzVScdotOcAxis,cdotOcMaxcOzVScdotOcAxis}} 
,ImageSize->{72. 6,72. 6/GoldenRatio}
];
