(*

Do the phase diagram in (cdot/c, c/z) space for the envy model

*)

<<DisplayOff.m;If[DisplayFigs == True,<<DisplayOn.m];

(* First do it for the habit formation case *)

<<params_Envy.m                 (* Set up parameter values *)
<<boundaries_Envy.m             (* Sets boundaries for the stable-arm generating routine *)
<<eqns_of_motion.m;             (* Set up equations of motion for Habits case *)
<<stable_arm.m                  (* Find the stable arm for the habits version *)


<<PhaseDiagramcOzVScdotOc.m;    (* Construct diagram components for Habits model *)

PhaseDiagcOzVScdotOcHabits = PhaseDiagcOzVScdotOc;

StableArm2DcOzVScdotOcRight =  
Plot[DevolvFuncRight2DcOzVScdotOc[x]
,{x,cOzMaxcOzVScdotOcPlot,cOzSS+epsilon}
,DisplayFunction->Identity
];

cdotOcAlldotIsZeroHabits = Plot[cdotOcIsZeroUpper[cOz]
,{cOz,cOzMin,cOzMaxcOzVScdotOcPlot}
,PlotStyle->Thickness[.001]
,DisplayFunction->Identity
];

<<eqns_of_motion_Envy.m;      (* Now read in the equations of motion for the Envy model *)
<<stable_arm_decen.m; 

(* The stable arm in the envy case is given by combining the equation for cdot/c with
the formula relating zdot/z to c/z, giving a function for cdot/c as a function of c/z *)

Clear[StableArmEnvy];
StableArmEnvy[cOz_]  := (1/sigma) (A - delta - theta + gamma (sigma - 1) rho (cOz - 1));

StableArmEnvyLocus = Plot[StableArmEnvy[cOz]
,{cOz,cOzLeftStartingPoint,cOzMaxcOzVScdotOcPlot}
(*,PlotStyle->{Dashing[{.01,.01}],Thickness[.004]}*)
,DisplayFunction->Identity];

PhaseDiagcOzVScdotOcEnvy = Show[(*StableArm2DcOzVScdotOcLeft
,StableArm2DcOzVScdotOcRight*)
(*,cdotOcAlldotIsZeroHabits*)
cOzAlldotIsZeroLocus
,StableArmEnvyLocus
(*,Graphics[Text["\!\(\(c\& . \)/c\) = 0" ,{cOzMaxcOzVScdotOcPlot+.1,1.7}]]*)
,Graphics[Text["\!\(\(\((c/z)\)\& . \)\) = 0"       ,{cOzMaxcOzVScdotOcPlot+.1,2.10},{-1,-1}]]
(*,Graphics[Text["Inward",{cOzMaxcOzVScdotOcPlot,1.35}]]*)
,Graphics[Text["Stable Arm",{cOzMaxcOzVScdotOcPlot+.2,1.15},{-1,-1}]]
,Graphics[Text["0",{-.1,-.2}]]
,Graphics[Text["1",{  1,-.2}]]
,Graphics[Text["SS",{cOzSS-.1,cdotOcSS+.15}]]
,AxesLabel->{"c/z","\!\(\(c\& . \)/c\)"}
,DisplayFunction->$DisplayFunction
,Ticks->None 
,PlotRange->{{cOzMincOzVScdotOcAxis,cOzMaxcOzVScdotOcAxis},{cdotOcMincOzVScdotOcAxis,cdotOcMaxcOzVScdotOcAxis}} 
,ImageSize->HalfPageSize
];

diroutenvy;
Display["PhaseDiagcOzVScdotOcEnvy.eps",PhaseDiagcOzVScdotOcEnvy,"EPS"];

StableArmEnvyLocusGray = Plot[StableArmEnvy[cOz]
,{cOz,cOzLeftStartingPoint,cOzMaxcOzVScdotOcPlot}
,PlotStyle->{Dashing[{.01,.01}],Thickness[.004]}
,DisplayFunction->Identity];

PhaseDiagcOzVScdotOcBoth = Show[StableArm2DcOzVScdotOcLeft
,StableArm2DcOzVScdotOcRight
,cdotOcAlldotIsZeroHabits
,cOzAlldotIsZeroLocus
,StableArmEnvyLocusGray
,Graphics[Text["\!\(\(c\& . \)/c\) = 0" ,{cOzMaxcOzVScdotOcPlot+.1,1.7},{-1,-1}]]
,Graphics[Text["\!\(\(\((c/z)\)\& . \)\) = 0"       ,{cOzMaxcOzVScdotOcPlot+.1,2.10},{-1,-1}]]
,Graphics[Text["Inward",{cOzMaxcOzVScdotOcPlot+.15,1.35},{-1,-1}]]
,Graphics[Text["Outward",{cOzMaxcOzVScdotOcPlot+.15,1.10},{-1,-1}]]
,Graphics[Text["0",{-.1,-.2}]]
,Graphics[Text["1",{  1,-.2}]]
,Graphics[Text["SS",{cOzSS-.1,cdotOcSS+.15}]]
,AxesLabel->{"c/z","\!\(\(\(c\& . \)/c\ \)\)"}
,DisplayFunction->$DisplayFunction
,Ticks->None 
,PlotRange->{{cOzMincOzVScdotOcAxis,cOzMaxcOzVScdotOcAxis},{cdotOcMincOzVScdotOcAxis,cdotOcMaxcOzVScdotOcAxis}} 
,ImageSize->HalfPageSize
];


Display["PhaseDiagcOzVScdotOcBoth.eps",PhaseDiagcOzVScdotOcBoth,"EPS"];
dirprog;