(*

Program to produce phase diagram in (c/z,k/z) space

eqns_of_motion.m, stable_arm.m, and boundaries.m must all 
have been run before running this program.

*)

Print["Running PhaseDiagramcOzVSkOz.m"];

<<DisplayOff.m;
If[DisplayFigs == True, (* then *) <<DisplayOn.m,<<DisplayOff.m];

(* 
Plot range must go only to the point which corresponds to the 
maximum desired value of kOz; this is necessary because it shoots
off to infinity.
*)

cOzWherekOzEqMax = kOzVScOzWherekOzAlldotEqZero[kOzMaxcOzVSkOz];

cOzVSkOzWherekOzAlldotEqZeroLocus = 
Plot[cOzVSkOzWherekOzAlldotEqZero[cOz]
,{cOz,Max[0,DevolvLeftcOzMin],cOzWherekOzEqMax}
,PlotStyle->{Thickness[.001]}
,Ticks->None
];


StableArm2DcOzVSkOz = Plot[DevolvFunc2DcOzVSkOz[cOz]
,{cOz,cOzMincOzVSkOz,cOzRightEdgeOfStableArm}
];

Asymptote = ListPlot[{{1+(1/rho)(A-delta),0},{1+(1/rho)(A-delta),kOzMaxcOzVSkOz+.7}},PlotJoined->True,PlotStyle->Dashing[{.01}]];


<<DisplayOff.m;If[DisplayFinalFigs == True,<<DisplayOn.m];

PhaseDiagramcOzVSkOz = Show[
StableArm2DcOzVSkOz
,cOzVSkOzWherekOzAlldotEqZeroLocus
,Asymptote
,Graphics[Text["\\dot{\\left(\\frac{k}{z}\\right)}=0",{kOzVScOzWherekOzAlldotEqZero[kOzMaxcOzVSkOz],kOzMaxcOzVSkOz+.7}]]
,Graphics[Text["\\mbox{Stable Arm}",{cOzRightEdgeOfStableArm+.5,DevolvFunc2DcOzVSkOz[cOzRightEdgeOfStableArm]+.3}]]
,AxesLabel->{"c/z","k/z"}
,Ticks->{{{1+(1/rho)(A-delta),"1+(1/\\rho)(A-\delta)"}},{}}
,PlotRange->{{cOzMincOzVSkOzPlot,cOzRightEdgeOfStableArm+1.5},{kOzMincOzVSkOz,kOzMaxcOzVSkOz+1}}
,DisplayFunction->$DisplayFunction
,AxesOrigin->{cOzMincOzVSkOzPlot,kOzMincOzVSkOz}
];

dirout;
WriteMathfig["PhaseDiagramcOzVSkOz"];
dirprog;

If[PrintFigs == True,PSPrint[PhaseDiagramcOzVSkOz]];
