(*

Generate the policy functions as a series of dots representing
successive periods in both models 





*)

ScaleFactor = 1;  (* ScaleFactor determines the time gap between dots; 3 
means 1/3 of a year *)

<<TimeSeries_params.m;

rho = .4;
<<CalcSS.m;

<<eqns_of_motion.m;
<<stable_arm.m;


<<eqns_of_motion_Envy.m;
<<stable_arm_decen.m;


<<DisplayOff.m;If[DisplayFigs == True,<<DisplayOn.m];

$DefaultFont = {"Times-Roman",14};

PointsLists         =  { DevolvPtskOzVScOz, DevolvPtskOzVScdotOc, 
DevolvPtskOzVSkOzAlldot, DevolvPtskOzVSkdotOk, DevolvPtskOzVSzdotOz, 
DevolvPtskOzVScdotOcAlldot, DevolvPtskOzVSsOy};
DPointsLists        =  
{DDevolvPtskOzVScOz,DDevolvPtskOzVScdotOc,DDevolvPtskOzVSkOzAlldot,DDevolvPtskOzVSkdotOk,DDevolvPtskOzVSzdotOz,DDevolvPtskOzVScdotOcAlldot, 
DDevolvPtskOzVSsOy};


VerticalAxisSeriesTeX  =  {"c/z","\dot{c}/c"         ,"~\ 
\dot{\\left(\\frac{k}{z}\\right)}","\dot{k}/k"         
,"\dot{z}/z"         ,"~\ \dot{\\left(\\frac{\dot{c}}{c}\\right)}","s/y"};
VerticalAxisSeries     =  {"c/h","\!\(\(c\& . \)\)/c","\!\(\((k/h)\& . 
\)\)"               ,"\!\(\(k\& . \)\)/k","\!\(\(h\& . 
\)\)/h","\!\(\(\((\(c\& . \)/c)\)\& . \)\)","s/y"};

PolFnsNames  =  
{"kOzVScOz","kOzVScdotOc","kOzVSkOzAlldot","kOzVSkdotOk","kOzVSzdotOz","kOzVScdotOcAlldot","kOzVSsOy"};

PolFns       =  PolFnsNames; (* Simple way to make it the right length *)
DPolFns      =  PolFnsNames; (* Simple way to make it the right length *)
CombinePolFns=  PolFnsNames; (* Simple way to make it the right length *)
SteadyState  =  PolFns;      (* Simple way to make it the right length *)


MinList      = 
{MinPtscOz,MinPtscdotOc,MinPtskOzAlldot,MinPtskdotOk,MinPtszdotOz,MinPtscdotOcAlldot,MinPtssOy};

MaxList      = 
{MaxPtscOz,MaxPtscdotOc,MaxPtskOzAlldot,MaxPtskdotOk,MaxPtszdotOz,MaxPtscdotOcAlldot,MaxPtssOy};


DMinList     = 
{DMinPtscOz,DMinPtscdotOc,DMinPtskOzAlldot,DMinPtskdotOk,DMinPtszdotOz,DMinPtscdotOcAlldot,DMinPtssOy};

DMaxList     = 
{DMaxPtscOz,DMaxPtscdotOc,DMaxPtskOzAlldot,DMaxPtskdotOk,DMaxPtszdotOz,DMaxPtscdotOcAlldot,DMaxPtssOy};



Do[
PolFnPlotMin[[i]] = Min[PolFnPlotMin[[i]],MinList[[i]]];
PolFnPlotMax[[i]] = Max[PolFnPlotMax[[i]],MaxList[[i]]];
PolFns[[i]] = ListPlot[PointsLists[[i]]
,PlotRange->{{0,kOzMaxDevolving},{MinList[[i]],MaxList[[i]]}}
,PlotLabel->"Policy Functions for " <> VerticalAxisSeries[[i]]
,AxesLabel->{"k/h",VerticalAxisSeries[[i]]}
,AxesOrigin->{0,MinList[[i]]}
,PlotStyle->{PointSize[.013]}
,Ticks->(TickFunction[#1,#2,TextFunction->TrimText,MinorLength->{0,0}]&)
];
SteadyState[[i]] = 
ListPlot[{{kOzSS,MinList[[i]]},{kOzSS,MaxList[[i]]}},PlotJoined->True,Ticks->None];

,{i,Length[PointsLists]}]


Do[
PolFnPlotMin[[i]] = Min[PolFnPlotMin[[i]],MinList[[i]]];
PolFnPlotMax[[i]] = Max[PolFnPlotMax[[i]],MaxList[[i]]];
DPolFns[[i]] = ListPlot[DPointsLists[[i]]
,PlotRange->{{0,kOzMaxDevolving},{MinList[[i]],MaxList[[i]]}}
,PlotLabel->"Policy Functions for " <> VerticalAxisSeries[[i]]
,AxesLabel->{"k/h",VerticalAxisSeries[[i]]}
,AxesOrigin->{0,MinList[[i]]}
,PlotStyle->{PointSize[.008]}
,Ticks->(TickFunction[#1,#2,TextFunction->TrimText,MinorLength->{0,0}]&)
];
,{i,Length[PointsLists]}]


If[DisplayFinalFigs == True,<<DisplayOn.m];

Do[
CombinePolFns[[i]] = Show[PolFns[[i]]
,SteadyState[[i]]
,DPolFns[[i]]]
,{i,Length[PointsLists]}]


PolicyFunctionscOzAndcdotOc    = 
GraphicsArray[{{CombinePolFns[[1]]},{CombinePolFns[[2]]}},DisplayFunction->$DisplayFunction,ImageSize->FullPageSize];

PolicyFunctionssOyAndkdotOk    = 
GraphicsArray[{{CombinePolFns[[7]]},{CombinePolFns[[4]]}},DisplayFunction->$DisplayFunction,ImageSize->FullPageSize];

PolicyFunctionskOzcdotOc       = 
GraphicsArray[{{CombinePolFns[[3]]},{CombinePolFns[[6]]}},DisplayFunction->$DisplayFunction,ImageSize->FullPageSize];


Show[PolicyFunctionscOzAndcdotOc];
Show[PolicyFunctionssOyAndkdotOk];

diroutenvy;
Display["PolicyFunctionscOzAndcdotOc.eps",PolicyFunctionscOzAndcdotOc,"EPS"];

Display["PolicyFunctionssOyAndkdotOk.eps",PolicyFunctionssOyAndkdotOk,"EPS"];

Display["PolicyFunctionskOzcdotOc.eps",PolicyFunctionskOzcdotOc,"EPS"];
dirprog;